@@ -457,6 +457,7 @@ throw(Description_Field_Unknow_Exception){
   }
 }
 
+#if 0
 const intifada::Type& intifada::Record::operator()(const Path_Name& name)const
 {
   const Type*pret=this->get_value(name);
@@ -468,8 +469,9 @@ intifada::Type& intifada::Record::operator()(const Path_Name& name)
   Type*pret=this->get_value(name);
   return *pret;
 }
+#endif
 
-const intifada::Type* intifada::Record::get_value(const Path_Name& name)const
+const intifada::Type& intifada::Record::get_value(const Path_Name& name)const
 {
   clog("Record") << "get_value(" << name << ")-->" << cendl;
   Path_Name subpart=name;
@@ -482,7 +484,7 @@ const intifada::Type* intifada::Record::get_value(const Path_Name& name)const
 
   if(df != NULL){
     if(subpart.empty()!=true){
-      ret=df->get_value(subpart);
+      ret=&df->get_value(subpart);
     }else{
 
       bool f = this->get_presence(name);
@@ -491,10 +493,10 @@ const intifada::Type* intifada::Record::get_value(const Path_Name& name)const
     }
   }else{}
   clog("Record") << "<--get_value(" << name << ")" << cendl;
-  return ret;
+  return *ret;
 }
 
-intifada::Type* intifada::Record::get_value(const Path_Name& name)
+intifada::Type& intifada::Record::get_value(const Path_Name& name)
 {
   clog("Record") << "get_value(" << name << ")-->" << cendl;
   Path_Name subpart=name;
@@ -507,7 +509,7 @@ intifada::Type* intifada::Record::get_value(const Path_Name& name)
 
   if(df != NULL){
     if(subpart.empty()!=true){
-      ret=df->get_value(subpart);
+      ret=&df->get_value(subpart);
     }else{
 
       bool f = this->get_presence(name);
@@ -518,9 +520,10 @@ intifada::Type* intifada::Record::get_value(const Path_Name& name)
     throw Description_Field_Unknow_Exception(name);
   }
   clog("Record") << "<--get_value(" << name << ")" << cendl;
-  return ret;
+  return *ret;
 }
 
+#if 0
 void intifada::Record::get_value(const Path_Name& name, intifada::Type& ret)const
 {
   const Type *t=this->get_value(name);
@@ -542,6 +545,7 @@ void intifada::Record::set_value(const Path_Name& name,const intifada::Type& ret
       throw Description_Field_Unknow_Exception(name);
     }
   }
+#endif
 
 intifada::Data_Field* intifada::Record::clone()const
 {
